@@ -3,14 +3,15 @@ use netscan::PortScanner;
 use netscan::PortScanType;
 use netscan::ScanStatus;
 use std::time::Duration;
+use std::net::{IpAddr, Ipv4Addr};
 
 fn main() {
     let mut port_scanner = match PortScanner::new(None) {
         Ok(scanner) => (scanner),
         Err(e) => panic!("Error creating scanner: {}", e),
     };
-    port_scanner.set_target_ipaddr("192.168.1.1");
-    port_scanner.set_range(1, 1000);
+    port_scanner.set_dst_ip(IpAddr::V4(Ipv4Addr::new(192, 168, 1, 1)));
+    port_scanner.set_dst_port_range(1, 1000);
     //port_scanner.add_target_port(22);
     //port_scanner.add_target_port(80);
     //port_scanner.add_target_port(443);
@@ -18,7 +19,7 @@ fn main() {
     port_scanner.set_timeout(Duration::from_millis(10000));
     //port_scanner.set_wait_time(Duration::from_millis(200));
     port_scanner.run_scan();
-    let result = port_scanner.get_result();
+    let result = port_scanner.get_scan_result();
     print!("Status: ");
     match result.scan_status {
         ScanStatus::Done => {println!("Done")},
@@ -26,8 +27,8 @@ fn main() {
         _ => {println!("Error")},
     }
     println!("Open Ports:");
-    for port in result.open_ports {
-        println!("{}", port);
+    for port in result.ports {
+        println!("{:?}", port);
     }
     println!("Scan Time: {:?}", result.scan_time);
     match port_scanner.get_scan_type() {
